==> ejc-technologymanage-impl-3.0.0-20221228.061103-23-sources.jar: com/ejianc/business/constructor/controller/FazdController.java <==
package com.ejianc.business.constructor.controller;

import java.io.Serializable;

import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.constructor.bean.FazdEntity;
import com.ejianc.business.constructor.service.IFazdService;
import com.ejianc.business.constructor.vo.FazdVO;

/**
 * 方案字典实体
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("fazd")
public class FazdController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "fazd";//此处需要根据实际修改

    @Autowired
    private IFazdService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<FazdVO> saveOrUpdate(@RequestBody FazdVO saveOrUpdateVO) {
    	FazdEntity entity = BeanMapper.map(saveOrUpdateVO, FazdEntity.class);
    	if(entity.getPid()!=null){
    	    entity.setChildFlag(1);
        }else{
    	    entity.setChildFlag(0);
        }
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	FazdVO vo = BeanMapper.map(entity, FazdVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FazdVO> queryDetail(Long id) {
    	FazdEntity entity = service.selectById(id);
    	FazdVO vo = BeanMapper.map(entity, FazdVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<FazdVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (FazdVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(FazdVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryList(@RequestBody QueryParam param) {

        return CommonResponse.success("查询列表数据成功！", service.pageList(param));
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<FazdEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Fazd-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refFazdData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FazdVO>> refFazdData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("qbm"); //编码
        fuzzyFields.add("mc");  //名称
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("status", new Parameter(QueryParam.EQ, 0));//字典状态 0启用

        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject con = JSONObject.parseObject(condition);
            Long mark=con.getLong("pid");
            //方案类型名称
            param.getParams().put("pid", new Parameter(QueryParam.EQ, mark));

        }
        IPage<FazdEntity> page = service.queryPage(param,false);
        IPage<FazdVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FazdVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    @RequestMapping(value = "/addChildByPId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FazdVO> addChildByPId(Long pid) {
        FazdVO vo = service.addChildByPId(pid);
        return CommonResponse.success("新增转换数据成功！", vo);
    }
}

==> ejc-technologymanage-impl-3.0.0-20251009.061228-54-sources.jar: com/ejianc/business/constructor/controller/FazdController.java <==
package com.ejianc.business.constructor.controller;

import java.io.Serializable;

import com.alibaba.fastjson.JSONArray;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.framework.core.util.ResultAsTree;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.constructor.bean.FazdEntity;
import com.ejianc.business.constructor.service.IFazdService;
import com.ejianc.business.constructor.vo.FazdVO;

/**
 * 方案字典实体
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("fazd")
public class FazdController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "fazd";//此处需要根据实际修改

    @Autowired
    private IFazdService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<FazdVO> saveOrUpdate(@RequestBody FazdVO saveOrUpdateVO) {
    	FazdEntity entity = BeanMapper.map(saveOrUpdateVO, FazdEntity.class);
    	if(entity.getPid()!=null){
    	    entity.setChildFlag(1);
        }else{
    	    entity.setChildFlag(0);
        }
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	FazdVO vo = BeanMapper.map(entity, FazdVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FazdVO> queryDetail(Long id) {
    	FazdEntity entity = service.selectById(id);
    	FazdVO vo = BeanMapper.map(entity, FazdVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<FazdVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (FazdVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(FazdVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryList(@RequestBody QueryParam param) {
        param.getOrderMap().clear();
        param.getOrderMap().put("qbm","asc");
        return CommonResponse.success("查询列表数据成功！", service.pageList(param));
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        param.getOrderMap().clear();
        param.getOrderMap().put("qbm","asc");
        JSONObject pageList = service.pageList(param);
        JSONArray jsonArray = pageList.getJSONArray("records");
        List<FazdVO> fazdVOS = jsonArray.toJavaList(FazdVO.class);

        ArrayList<FazdVO> list = new ArrayList<>();
        for (FazdVO fazdVO : fazdVOS) {
            list.add(fazdVO);
            List<FazdVO> children = fazdVO.getChildren();
            list.addAll(children);
        }

        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Fazd-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refFazdData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FazdVO>> refFazdData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("qbm"); //编码
        fuzzyFields.add("mc");  //名称
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("status", new Parameter(QueryParam.EQ, 0));//字典状态 0启用

        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject con = JSONObject.parseObject(condition);
            Long mark=con.getLong("pid");
            //方案类型名称
            param.getParams().put("pid", new Parameter(QueryParam.EQ, mark));

        }
        IPage<FazdEntity> page = service.queryPage(param,false);
        IPage<FazdVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FazdVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    @RequestMapping(value = "/addChildByPId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FazdVO> addChildByPId(Long pid) {
        FazdVO vo = service.addChildByPId(pid);
        return CommonResponse.success("新增转换数据成功！", vo);
    }

    /**
     * @Description 树表参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refFazdTreeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FazdVO>> refFazdTreeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                     String condition,
                                                     String searchObject,
                                                     String searchText,
                                                     String relyCondition) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("qbm"); //编码
        fuzzyFields.add("mc");  //名称
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("status", new Parameter(QueryParam.EQ, 0));//字典状态 0启用

        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject con = JSONObject.parseObject(condition);
            if(null != con.get("pid")){
                param.getParams().put("pid", new Parameter(QueryParam.EQ, con.getLong("pid")));
            }

        }
        if(StringUtils.isNotEmpty(relyCondition)){
            /** relyCondition */
            Long pid = Long.parseLong(relyCondition.split("=")[1]);
            param.getParams().put("pid", new Parameter(QueryParam.EQ, pid));


        }
        IPage<FazdEntity> page = service.queryPage(param,false);
        IPage<FazdVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FazdVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
    }

    /**
     * 参照异步（懒加载）树----方案字典树
     *
     * @param condition
     * @param searchText
     * @return
     */
    @RequestMapping(value = "/lazyFazdTree", method = RequestMethod.GET)
    @ResponseBody
    public List<Map<String, Object>> lazyFazdTree(@RequestParam(required=false) String condition,
                                                  @RequestParam(required=false) Long pid,
                                                  @RequestParam(required = false) String searchText) {
        List<FazdVO> dataList = null;
        try {
            Map<String,Object> params = new HashMap<>();
            if(StringUtils.isNotBlank(searchText)) {
                params.put("searchText", searchText);
                params.put("tenantId", InvocationInfoProxy.getTenantid());
                /*if(StringUtils.isNotBlank(condition)){
                 *//** 处理condition *//*
					JSONObject con = JSONObject.parseObject(condition);
					Object categoryId = con.get("categoryId");
					if (null != categoryId && pid == null) {
						params.put("categoryId", categoryId);
					}
				}*/
            }
            dataList = service.queryListTree(params);

//            else{
//                dataList = service.queryListByPid(pid);
//                if(StringUtils.isNotBlank(condition)){
//                    /** 处理condition */
//                    JSONObject con = JSONObject.parseObject(condition);
//                    Object categoryIdObj = con.get("categoryId");
//                    if (null != categoryIdObj && pid == null) {
//                        List<Long> asList = new ArrayList<>();
//                        String categoryId = ((String) categoryIdObj);
//                        if(categoryId.indexOf(",") > 0){
//                            String[] strings = categoryId.split(",");
//                            for(String str : strings){
//                                asList.add(Long.valueOf(str));
//                            }
//                        }else{
//                            asList.add(Long.valueOf(categoryId));
//                        }
//                        dataList = materialCategoryService.queryCategoryListByIds(asList);
//                    }
//                }
//            }
            List<Map> maps = BeanMapper.mapList(dataList, Map.class);
//            List<Map> maps = new ArrayList<>();
            for (Map map : maps) {
                String name =  map.get("mc").toString();
                map.remove("mc");
                map.put("name",name);

                String parentId = (map.get("pid") != null) ? map.get("pid").toString():"";
                map.remove("pid");
                map.put("parentId",parentId);
            }
            return ResultAsTree.createTreeData(maps);
        } catch (Exception e) {
            return null;
        }
    }
}
